<?php

namespace Bixo\Parser\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Bixo\Parser\Http\Requests\ParserRequest;
use Bixo\Parser\Models\Parser;

/**
 * Admin web controller class.
 */
class ParserWorkflowController extends BaseController
{

    /**
     * Workflow controller function for parser.
     *
     * @param Model   $parser
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(ParserRequest $request, Parser $parser, $step)
    {

        try {

            $parser->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('parser::parser.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/parser/parser/' . $parser->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/parser/parser/' . $parser->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for parser.
     *
     * @param Model   $parser
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(Parser $parser, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $parser->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('parser::parser.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('parser::admin.parser.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('parser::admin.parser.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('parser::admin.parser.message', $data)->render();

        }

    }
}
