<?php

namespace Bixo\Parser\Policies;

use Litepie\User\Contracts\UserPolicy;
use Bixo\Parser\Models\Parser;

class ParserPolicy
{

    /**
     * Determine if the given user can view the parser.
     *
     * @param UserPolicy $user
     * @param Parser $parser
     *
     * @return bool
     */
    public function view(UserPolicy $user, Parser $parser)
    {
        if ($user->canDo('parser.parser.view') && $user->isAdmin()) {
            return true;
        }

        return $parser->user_id == user_id() && $parser->user_type == user_type();
    }

    /**
     * Determine if the given user can create a parser.
     *
     * @param UserPolicy $user
     * @param Parser $parser
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('parser.parser.create');
    }

    /**
     * Determine if the given user can update the given parser.
     *
     * @param UserPolicy $user
     * @param Parser $parser
     *
     * @return bool
     */
    public function update(UserPolicy $user, Parser $parser)
    {
        if ($user->canDo('parser.parser.edit') && $user->isAdmin()) {
            return true;
        }

        return $parser->user_id == user_id() && $parser->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given parser.
     *
     * @param UserPolicy $user
     * @param Parser $parser
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Parser $parser)
    {
        return $parser->user_id == user_id() && $parser->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given parser.
     *
     * @param UserPolicy $user
     * @param Parser $parser
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Parser $parser)
    {
        if ($user->canDo('parser.parser.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given parser.
     *
     * @param UserPolicy $user
     * @param Parser $parser
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Parser $parser)
    {
        if ($user->canDo('parser.parser.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
