<?php

namespace Bixo\Parser\Workflow;

use Bixo\Parser\Models\Parser;
use Validator;

class ParserValidator
{

    /**
     * Determine if the given parser is valid for complete status.
     *
     * @param Parser $parser
     *
     * @return bool / Validator
     */
    public function complete(Parser $parser)
    {
        return Validator::make($parser->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given parser is valid for verify status.
     *
     * @param Parser $parser
     *
     * @return bool / Validator
     */
    public function verify(Parser $parser)
    {
        return Validator::make($parser->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given parser is valid for approve status.
     *
     * @param Parser $parser
     *
     * @return bool / Validator
     */
    public function approve(Parser $parser)
    {
        return Validator::make($parser->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given parser is valid for publish status.
     *
     * @param Parser $parser
     *
     * @return bool / Validator
     */
    public function publish(Parser $parser)
    {
        return Validator::make($parser->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given parser is valid for archive status.
     *
     * @param Parser $parser
     *
     * @return bool / Validator
     */
    public function archive(Parser $parser)
    {
        return Validator::make($parser->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given parser is valid for unpublish status.
     *
     * @param Parser $parser
     *
     * @return bool / Validator
     */
    public function unpublish(Parser $parser)
    {
        return Validator::make($parser->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
